@@ -1,5 +1,5 @@
 #! /usr/bin/env bash
 #$EXTRACTRC `find . -name "*.ui"` >> rc.cpp || exit 11
 $EXTRACTQML `find . -name "*.qml"` >> rc.cpp
-$XGETTEXT *.cpp -o $podir/plasma_presence_applet.pot
+$XGETTEXT *.cpp -o $podir/org.kde.telepathy-presence.pot
 rm -f rc.cpp
